<?php
/**
 * Set the content width based on the theme's design and stylesheet.
 */
 
//Content width 
if ( ! isset( $content_width ) ) {
	$content_width = 900;
}


//Body class
add_filter('body_class','pvs_body_class');
function pvs_body_class( $classes ) {

	foreach ( $classes as $key => $value ) {
		unset($classes[$key]);
	}

	return $classes;
}



//Js scripts
function pvs_theme_js_scripts() {
	if ( is_singular() ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'pvs_theme_js_scripts' );


//The theme supports:
add_theme_support( 'automatic-feed-links' );
add_theme_support( 'title-tag' );
add_theme_support( 'post-thumbnails' );
add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
	) );
add_theme_support( 'post-formats', array(
		'aside'
	) );


//Disable top admin panel
add_filter('show_admin_bar', '__return_false');


//Widgets
function pvs_widgets(){
	register_sidebar( array(
		'name'          => __( 'Footer area 1', 'pvs-theproject' ),
		'id'            => 'sidebar-footer-area-1',
		'description'   => '',
		'before_widget' => '<div id="%1$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="title">',
		'after_title'   => '</h2><div class="separator-2"></div>',
	) );
	register_sidebar( array(
		'name'          => __( 'Footer area 2', 'pvs-theproject' ),
		'id'            => 'sidebar-footer-area-2',
		'description'   => '',
		'before_widget' => '<div id="%1$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="title">',
		'after_title'   => '</h2><div class="separator-2"></div>',
	) );
	register_sidebar( array(
		'name'          => __( 'Footer area 3', 'pvs-theproject' ),
		'id'            => 'sidebar-footer-area-3',
		'description'   => '',
		'before_widget' => '<div id="%1$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="title">',
		'after_title'   => '</h2><div class="separator-2"></div>',
	) );
	register_sidebar( array(
		'name'          => __( 'Footer area 4', 'pvs-theproject' ),
		'id'            => 'sidebar-footer-area-4',
		'description'   => '',
		'before_widget' => '<div id="%1$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h2 class="title">',
		'after_title'   => '</h2><div class="separator-2"></div>',
	) );
}
add_action( 'widgets_init', 'pvs_widgets' );


//Theme header/footer for internal pages
$pvs_theme_header = '<div class="container second_page">' ;
$pvs_theme_footer = '</div>';


if ( defined( 'PVS_NAME' ) ) {
	pvs_content();
	
	//Remove unnecessary js scripts and css
	add_action( 'wp_print_scripts', 'pvs_remove_scripts');
	add_action( 'wp_print_styles', 'pvs_remove_styles');

	function pvs_remove_scripts() {
		wp_dequeue_script( 'jquery' );
		wp_deregister_script( 'jquery' );
		
		wp_dequeue_script( 'pvs_jquery' );
		wp_deregister_script( 'pvs_jquery' );
		
		wp_dequeue_script( 'pvs_jqueryui' );
		wp_deregister_script( 'pvs_jqueryui' );
		
		wp_dequeue_script( 'bootstrap' );
		wp_deregister_script( 'bootstrap' );
		
		wp_dequeue_script( 'pvs_jshttprequest' );
		wp_deregister_script( 'pvs_jshttprequest' );
		
		wp_dequeue_script( 'pvs_custom_js' );
		wp_deregister_script( 'pvs_custom_js' );
	}
		
	function pvs_remove_styles() {		
		wp_dequeue_style( 'pvs_css' );
		wp_deregister_style( 'pvs_css' );
		
		wp_dequeue_style( 'bootstrap_style' );
		wp_deregister_style( 'bootstrap_style' );
	}
}



//Customize
function pvs_theproject_customize($wp_customize) {

	//Logo
    $wp_customize->add_section(
        'pvs_theproject_logo',
        array(
            'title' => 'Logo',
            'description' => '',
            'priority' => 1,
        )
    );
	
	$wp_customize->add_setting( 
    	'logo', 
    	array(
			'default' => get_template_directory_uri() . '/assets/images/logo.png',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
    );
 
	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'logo',
			array(
				'label' => 'Logo',
				'section' => 'pvs_theproject_logo',
				'settings' => 'logo'
			)
		)
	);
	
	
	$wp_customize->add_setting(
		'logo_subtitle',
		array(
			'default' => 'Professional software for photographers',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'logo_subtitle',
		array(
			'label' => 'Subtitle',
			'section' => 'pvs_theproject_logo',
			'type' => 'text',
		)
	);
	//End. Logo
	
	//Slideshow
	$wp_customize->add_section(
        'pvs_theproject_slideshow',
        array(
            'title' => 'Homepage Slideshow',
            'description' => '',
            'priority' => 2,
        )
    );
    
    $wp_customize->add_setting(
		'hide_slideshow'
	);
	
	$wp_customize->add_control(
		'hide_slideshow',
		array(
			'label' => 'Hide Slideshow',
			'section' => 'pvs_theproject_slideshow',
			'type' => 'checkbox',
		)
	);
    
    //Slide 1
    $wp_customize->add_setting( 
    	'slider1_upload', 
    	array(
			'default' => get_template_directory_uri() . '/assets/images/slide1.jpg',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
    );
 
	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'slider1_upload',
			array(
				'label' => 'Slide 1 Upload',
				'section' => 'pvs_theproject_slideshow',
				'settings' => 'slider1_upload'
			)
		)
	);
    
	//End. Slide 1
	
	//Slide 2
	$wp_customize->add_setting( 
    	'slider2_upload', 
    	array(
			'default' => get_template_directory_uri() . '/assets/images/slide2.jpg',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
    );
 
	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'slider2_upload',
			array(
				'label' => 'Slide 2 Upload',
				'section' => 'pvs_theproject_slideshow',
				'settings' => 'slider2_upload'
			)
		)
	);
    
	//End. Slide 2
	

	//End. Slideshow
	
	

	
	
	//Photo stock
	$wp_customize->add_section(
        'pvs_theproject_photo_stock',
        array(
            'title' => 'Homepage Photo Stock',
            'description' => '',
            'priority' => 4,
        )
    );
    
    $wp_customize->add_setting(
		'hide_photo_stock'
	);
	
	$wp_customize->add_control(
		'hide_photo_stock',
		array(
			'label' => 'Hide photo stock',
			'section' => 'pvs_theproject_photo_stock',
			'type' => 'checkbox',
		)
	);
	
	$wp_customize->add_setting(
		'photo_stock_title',
		array(
			'default' => 'Photo Stock',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'photo_stock_title',
		array(
			'label' => 'Title',
			'section' => 'pvs_theproject_photo_stock',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'photo_stock_description',
		array(
			'default' => 'Lorem ipsum dolor sit amet, consectetur adipisicing elit. Voluptas nulla suscipit 
unde rerum mollitia dolorum.',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'photo_stock_description',
		array(
			'label' => 'Description',
			'section' => 'pvs_theproject_photo_stock',
			'type' => 'text',
		)
	);
	
	//End. Photo Stock
	



	//Map
	$wp_customize->add_section(
        'pvs_theproject_map',
        array(
            'title' => 'Homepage Map',
            'description' => '',
            'priority' => 4,
        )
    );
    
    $wp_customize->add_setting(
		'hide_map'
	);
	
	$wp_customize->add_control(
		'hide_map',
		array(
			'label' => 'Hide map',
			'section' => 'pvs_theproject_map',
			'type' => 'checkbox',
		)
	);
	//End. Map
	
	
	
	//Blue section
	$wp_customize->add_section(
        'pvs_theproject_blue_section',
        array(
            'title' => 'Homepage Blue section',
            'description' => '',
            'priority' => 4,
        )
    );
    
    $wp_customize->add_setting(
		'hide_blue_section'
	);
	
	$wp_customize->add_control(
		'hide_blue_section',
		array(
			'label' => 'Hide blue section',
			'section' => 'pvs_theproject_blue_section',
			'type' => 'checkbox',
		)
	);
	
	$wp_customize->add_setting(
		'blue_section_title',
		array(
			'default' => 'Don\'t Miss Out Our Offers',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'blue_section_title',
		array(
			'label' => 'Title',
			'section' => 'pvs_theproject_blue_section',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'blue_section_description',
		array(
			'default' => 'Lorem ipsum dolor sit amet, consectetur adipisicing elit. Rem quasi explicabo consequatur consectetur, a atque voluptate officiis eligendi nostrum.',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'blue_section_description',
		array(
			'label' => 'Description',
			'section' => 'pvs_theproject_blue_section',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'blue_section_link_text',
		array(
			'default' => 'Learn more',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'blue_section_link_text',
		array(
			'label' => 'Link text',
			'section' => 'pvs_theproject_blue_section',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'blue_section_link',
		array(
			'default' => '',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'blue_section_link',
		array(
			'label' => 'Link',
			'section' => 'pvs_theproject_blue_section',
			'type' => 'text',
		)
	);
	
	//End. Blue section
	
	
	
	//Core features
	$wp_customize->add_section(
        'pvs_theproject_core_features',
        array(
            'title' => 'Home page Core features',
            'description' => '',
            'priority' => 4,
        )
    );
    
    $wp_customize->add_setting(
		'hide_core_features'
	);
	
	$wp_customize->add_control(
		'hide_core_features',
		array(
			'label' => 'Hide core features',
			'section' => 'pvs_theproject_core_features',
			'type' => 'checkbox',
		)
	);
	
	$wp_customize->add_setting(
		'core_features_title',
		array(
			'default' => 'Core features',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'core_features_title',
		array(
			'label' => 'Title',
			'section' => 'pvs_theproject_core_features',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'core_features_description',
		array(
			'default' => 'Lorem ipsum dolor sit amet, consectetur adipisicing elit. Numquam voluptas facere vero ex tempora saepe perspiciatis ducimus sequi animi.',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'core_features_description',
		array(
			'label' => 'Description',
			'section' => 'pvs_theproject_core_features',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'core_features_title1',
		array(
			'default' => 'Clean Code &amp; Design',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'core_features_title1',
		array(
			'label' => 'Column 1 - Title',
			'section' => 'pvs_theproject_core_features',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'core_features_icon1',
		array(
			'default' => 'fa fa-diamond',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'core_features_icon1',
		array(
			'label' => 'Column 1 - Icon',
			'section' => 'pvs_theproject_core_features',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'core_features_description1',
		array(
			'default' => 'Voluptatem ad provident non repudiandae beatae cupiditate amet reiciendis lorem ipsum dolor sit amet, consectetur.',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'core_features_description1',
		array(
			'label' => 'Column 1 - Description',
			'section' => 'pvs_theproject_core_features',
			'type' => 'text',
		)
	);
	
	
	$wp_customize->add_setting(
		'core_features_link_text1',
		array(
			'default' => 'Read More',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'core_features_link_text1',
		array(
			'label' => 'Column 1 - Link text',
			'section' => 'pvs_theproject_core_features',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'core_features_link1',
		array(
			'default' => '#',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'core_features_link1',
		array(
			'label' => 'Column 1 - Link',
			'section' => 'pvs_theproject_core_features',
			'type' => 'text',
		)
	);
	





	
	$wp_customize->add_setting(
		'core_features_title2',
		array(
			'default' => 'Extremely Flexible',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'core_features_title2',
		array(
			'label' => 'Column 2 - Title',
			'section' => 'pvs_theproject_core_features',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'core_features_icon2',
		array(
			'default' => 'fa fa-connectdevelop',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'core_features_icon2',
		array(
			'label' => 'Column 2 - Icon',
			'section' => 'pvs_theproject_core_features',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'core_features_description2',
		array(
			'default' => 'Iure sequi unde hic. Sapiente quaerat sequi inventore veritatis cumque lorem ipsum dolor sit amet, consectetur.',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'core_features_description2',
		array(
			'label' => 'Column 2 - Description',
			'section' => 'pvs_theproject_core_features',
			'type' => 'text',
		)
	);
	
	
	$wp_customize->add_setting(
		'core_features_link_text2',
		array(
			'default' => 'Read More',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'core_features_link_text2',
		array(
			'label' => 'Column 2 - Link text',
			'section' => 'pvs_theproject_core_features',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'core_features_link2',
		array(
			'default' => '#',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'core_features_link2',
		array(
			'label' => 'Column 2 - Link',
			'section' => 'pvs_theproject_core_features',
			'type' => 'text',
		)
	);
	





	
	$wp_customize->add_setting(
		'core_features_title3',
		array(
			'default' => 'Latest Technologies',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'core_features_title3',
		array(
			'label' => 'Column 3 - Title',
			'section' => 'pvs_theproject_core_features',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'core_features_icon3',
		array(
			'default' => 'fa icon-snow',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'core_features_icon3',
		array(
			'label' => 'Column 3 - Icon',
			'section' => 'pvs_theproject_core_features',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'core_features_description3',
		array(
			'default' => 'Inventore dolores aut laboriosam cum consequuntur delectus sequi lorem ipsum dolor sit amet, consectetur.',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'core_features_description3',
		array(
			'label' => 'Column 3 - Description',
			'section' => 'pvs_theproject_core_features',
			'type' => 'text',
		)
	);
	
	
	$wp_customize->add_setting(
		'core_features_link_text3',
		array(
			'default' => 'Read More',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'core_features_link_text3',
		array(
			'label' => 'Column 3 - Link text',
			'section' => 'pvs_theproject_core_features',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'core_features_link3',
		array(
			'default' => '#',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'core_features_link3',
		array(
			'label' => 'Column 3 - Link',
			'section' => 'pvs_theproject_core_features',
			'type' => 'text',
		)
	);	
	//End. Core features
	
	
	
	
	
	//Stats
	$wp_customize->add_section(
        'pvs_theproject_stats',
        array(
            'title' => 'Homepage Stats',
            'description' => '',
            'priority' => 4,
        )
    );
    
    $wp_customize->add_setting(
		'hide_stats'
	);
	
	$wp_customize->add_control(
		'hide_stats',
		array(
			'label' => 'Hide stats',
			'section' => 'pvs_theproject_stats',
			'type' => 'checkbox',
		)
	);
	//End. Stats




	//Black section
	$wp_customize->add_section(
        'pvs_theproject_black_section',
        array(
            'title' => 'Footer Black section',
            'description' => '',
            'priority' => 6,
        )
    );
    
    $wp_customize->add_setting(
		'hide_black_section'
	);
	
	$wp_customize->add_control(
		'hide_black_section',
		array(
			'label' => 'Hide black section',
			'section' => 'pvs_theproject_black_section',
			'type' => 'checkbox',
		)
	);
	
	$wp_customize->add_setting(
		'black_section_title',
		array(
			'default' => 'Stock photos, royalty-free images',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'black_section_title',
		array(
			'label' => 'Title',
			'section' => 'pvs_theproject_black_section',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'black_section_title2',
		array(
			'default' => 'Perfect stock for you',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'black_section_title2',
		array(
			'label' => 'Title 2',
			'section' => 'pvs_theproject_black_section',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'black_section_link_text',
		array(
			'default' => 'Purchase',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'black_section_link_text',
		array(
			'label' => 'Link text',
			'section' => 'pvs_theproject_black_section',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'black_section_link',
		array(
			'default' => '/index.php?search=',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'black_section_link',
		array(
			'label' => 'Link',
			'section' => 'pvs_theproject_black_section',
			'type' => 'text',
		)
	);
	
	//End. Black section	
	
	
	//Footer
    $wp_customize->add_section(
        'pvs_theproject_footer',
        array(
            'title' => 'Footer',
            'description' => '',
            'priority' => 7,
        )
    );
    
    $wp_customize->add_setting(
		'footer_text',
		array(
			'default' => 'Professional software for photographers and video producers.',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'footer_text',
		array(
			'label' => 'Footer text',
			'section' => 'pvs_theproject_footer',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'footer_copyright_year',
		array(
			'default' => '2018',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'footer_copyright_year',
		array(
			'label' => 'Year',
			'section' => 'pvs_theproject_footer',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'footer_copyright_text',
		array(
			'default' => 'Photo Video Store',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'footer_copyright_text',
		array(
			'label' => 'Copyright',
			'section' => 'pvs_theproject_footer',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'footer_copyright_link',
		array(
			'default' => 'https://www.cmsaccount.com/',
			'sanitize_callback' => 'pvs_theproject_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'footer_copyright_link',
		array(
			'label' => 'Copyright Link',
			'section' => 'pvs_theproject_footer',
			'type' => 'text',
		)
	);
	//End. Footer
}

add_action('customize_register', 'pvs_theproject_customize' );

function pvs_theproject_sanitize_text( $input ) {
    return wp_kses_post( force_balance_tags( $input ) );
}
//End. Customize



// Bootstrap pagination function
function wp_bs_pagination($pages = '', $range = 4)
{  
     $showitems = ($range * 2) + 1;  

     global $paged;
 
     if(empty($paged)) $paged = 1;
 
     if($pages == '') 
     { 
         global $wp_query; 
 
		 $pages = $wp_query->max_num_pages;
 
         if(!$pages) 
         { 
             $pages = 1;
 
         } 
     }   
  
     if(1 != $pages) 
     { 
        echo '<div class="text-center">'; 
        //echo '<nav><ul class="pagination"><li class="disabled hidden-xs"><span><span aria-hidden="true">Page '.$paged.' of '.$pages.'</span></span></li>';
        echo '<nav><ul class="pagination">';
 
         if($paged > 2 && $paged > $range+1 && $showitems < $pages) echo "<li><a href='".get_pagenum_link(1)."' aria-label='First'>&laquo;<span class='hidden-xs'> First</span></a></li>";
 
         if($paged > 1 && $showitems < $pages) echo "<li><a href='".get_pagenum_link($paged - 1)."' aria-label='Previous'>&lsaquo;<span class='hidden-xs'> Previous</span></a></li>";
  
         for ($i=1; $i <= $pages; $i++) 
         { 
             if (1 != $pages &&( !($i >= $paged+$range+1 || $i <= $paged-$range-1) || $pages <= $showitems )) 
             {
 
                 echo ($paged == $i)? "<li class=\"active\"><a><span>".$i." <span class=\"sr-only\">(current)</span></span></a>
 
    </li>":"<li><a href='".get_pagenum_link($i)."'>".$i."</a></li>";
 
             }
 
         }
  
         if ($paged < $pages && $showitems < $pages) echo "<li><a href=\"".get_pagenum_link($paged + 1)."\"  aria-label='Next'><span class='hidden-xs'>Next </span>&rsaquo;</a></li>";  
 
         if ($paged < $pages-1 &&  $paged+$range-1 < $pages && $showitems < $pages) echo "<li><a href='".get_pagenum_link($pages)."' aria-label='Last'><span class='hidden-xs'>Last </span>&raquo;</a></li>";
 
         echo "</ul></nav>";
         echo "</div>";
     }

}
?>